@@ -52,7 +52,7 @@ sub update ( $type, $cv = undef ) {
 
                 IO::Uncompress::Gunzip::gunzip( $res->body, $temp->path, BinModeOut => 1 );
 
-                $ENV->share->store( $temp->path, $RES->{$type}->[0], 'pcore-geoip' );
+                $ENV->share->store( $temp->path, $RES->{$type}->[0], 'Pcore-GeoIP' );
 
                 delete $H->{$type};
             }
